==> php83-nextcloud-28.0.6.tgz: share/nextcloud/apps/text/l10n/oc.js <==
OC.L10N.register(
    "text",
    {
    "The file was uploaded" : "Lo fichièr es estat enviat",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Lo fichièr enviat despassa la directiva upload_max_filesize de php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Lo fichièr enviat despassa la directiva MAX_FILE_SIZE especificada dins lo formulari HTML",
    "The file was only partially uploaded" : "Lo fichièr es estat parcialament enviat",
    "No file was uploaded" : "Cap de fichièr pas enviat",
    "Missing a temporary folder" : "Dossièr temporari absent",
    "Could not write file to disk" : "Escritura impossibla al disc",
    "A PHP extension stopped the file upload" : "Una extension PHP a arrestat lo mandadís de fichièr",
    "Nextcloud Text" : "Nextcloud Text",
    "text document" : "document tèxt",
    "Readme" : "Readme",
    "Text" : "Tèxt",
    "📝 Collaborative document editing" : "📝 Edicion collaborativa de document",
    "Translate" : "Translate",
    "Use current version" : "Utilizar la version actuala",
    "Use the saved version" : "Utilizar la version salvada",
    "Reload" : "Recargar",
    "Reconnect" : "Se reconnectar",
    "Edit guest name" : "Modificar lo nom de convidat",
    "Guest" : "Convidat",
    "Save guest name" : "Enregistrar lo nom de convidat",
    "Insert an attachment" : "Inserir una pèça junta",
    "guest" : "convidat",
    "Show author colors" : "Afichar las colors dels utilizaires",
    "Last saved" : "Darrièra salvagarda",
    "Offline" : "Fòra linha",
    "Saving …" : "Enregistrament...",
    "Saved" : "Enregistrat",
    "Last saved {lastSave}" : "Darrièra salvagarda {lastSave}",
    "The document has been changed outside of the editor. The changes cannot be applied." : "Lo document es estat modificar defòra de l’editor. Se pòdon pas aplicar las modificacions.",
    "Unsaved changes" : "Modificacions pas enregistradas",
    "Keyboard shortcuts" : "Acorchis de clavièr",
    "Bold" : "Gras",
    "Italic" : "Italica",
    "Heading 1" : "Títol 1",
    "Heading 6" : "Títol 6",
    "Unordered list" : "Lista pas ordenada",
    "Ordered list" : "Lista ordenada",
    "Blockquote" : "Citacion",
    "Code block" : "Còdi",
    "Insert emoji" : "Inserir emoji",
    "Undo" : "Anullar",
    "Redo" : "Refar",
    "Edit link" : "Modificar lo ligam",
    "Save changes" : "Salvar modificacions",
    "Cancel" : "Anullar",
    "URL" : "URL",
    "Remaining actions" : "Mai d’accions",
    "Select language" : "Causir lenga",
    "to" : "a",
    "Edit" : "Modificar",
    "Source code" : "Còdi font",
    "Delete this table" : "Suprimir aqueste tablèu",
    "Headings" : "Títols",
    "Heading 2" : "Títol 2",
    "Heading 3" : "Títol 3",
    "Heading 4" : "Títol 4",
    "Heading 5" : "Títol 5",
    "Insert link" : "Inserir un ligam",
    "Info" : "Info",
    "Success" : "Succès",
    "Warning" : "Avertiment",
    "Table" : "Tablèu",
    "Insert attachment" : "Inserir una pèça junta",
    "Command" : "Comanda",
    "Add notes, lists or links …" : "Apondre nòtas, listas o ligams…"
},
"nplurals=2; plural=(n > 1);");

==> php83-nextcloud-30.0.11.tgz: share/nextcloud/apps/text/l10n/oc.js <==
OC.L10N.register(
    "text",
    {
    "The file was uploaded" : "Lo fichièr es estat enviat",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Lo fichièr enviat despassa la directiva upload_max_filesize de php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Lo fichièr enviat despassa la directiva MAX_FILE_SIZE especificada dins lo formulari HTML",
    "The file was only partially uploaded" : "Lo fichièr es estat parcialament enviat",
    "No file was uploaded" : "Cap de fichièr pas enviat",
    "Missing a temporary folder" : "Dossièr temporari absent",
    "Could not write file to disk" : "Escritura impossibla al disc",
    "A PHP extension stopped the file upload" : "Una extension PHP a arrestat lo mandadís de fichièr",
    "Nextcloud Text" : "Nextcloud Text",
    "text document" : "document tèxt",
    "File not found" : "Fichièr pas trobat",
    "Readme" : "Readme",
    "Text" : "Tèxt",
    "📝 Collaborative document editing" : "📝 Edicion collaborativa de document",
    "Translate" : "Translate",
    "Reload" : "Recargar",
    "Reconnect" : "Se reconnectar",
    "Edit guest name" : "Modificar lo nom de convidat",
    "Guest" : "Convidat",
    "Save guest name" : "Enregistrar lo nom de convidat",
    "Insert an attachment" : "Inserir una pèça junta",
    "guest" : "convidat",
    "Offline" : "Fòra linha",
    "Saving …" : "Enregistrament...",
    "Saved" : "Enregistrat",
    "Last saved {lastSave}" : "Darrièra salvagarda {lastSave}",
    "The document has been changed outside of the editor. The changes cannot be applied." : "Lo document es estat modificar defòra de l’editor. Se pòdon pas aplicar las modificacions.",
    "Unsaved changes" : "Modificacions pas enregistradas",
    "Last saved" : "Darrièra salvagarda",
    "Keyboard shortcuts" : "Acorchis de clavièr",
    "Bold" : "Gras",
    "Italic" : "Italica",
    "Heading 1" : "Títol 1",
    "Heading 6" : "Títol 6",
    "Unordered list" : "Lista pas ordenada",
    "Ordered list" : "Lista ordenada",
    "Blockquote" : "Citacion",
    "Code block" : "Còdi",
    "Link" : "Ligam",
    "Insert emoji" : "Inserir emoji",
    "Undo" : "Anullar",
    "Redo" : "Refar",
    "Edit link" : "Modificar lo ligam",
    "Save changes" : "Salvar modificacions",
    "Cancel" : "Anullar",
    "URL" : "URL",
    "Remaining actions" : "Mai d’accions",
    "Select language" : "Causir lenga",
    "to" : "a",
    "Upload" : "Telecargament",
    "Edit" : "Modificar",
    "Source code" : "Còdi font",
    "Delete this table" : "Suprimir aqueste tablèu",
    "Headings" : "Títols",
    "Heading 2" : "Títol 2",
    "Heading 3" : "Títol 3",
    "Heading 4" : "Títol 4",
    "Heading 5" : "Títol 5",
    "Table" : "Tablèu",
    "Details" : "Per lo Menut",
    "Insert link" : "Inserir un ligam",
    "Insert attachment" : "Inserir una pèça junta",
    "Command" : "Comanda",
    "Choose" : "Causir",
    "Use current version" : "Utilizar la version actuala",
    "Use the saved version" : "Utilizar la version salvada",
    "Show author colors" : "Afichar las colors dels utilizaires",
    "Info" : "Info",
    "Success" : "Succès",
    "Warning" : "Avertiment",
    "Add notes, lists or links …" : "Apondre nòtas, listas o ligams…"
},
"nplurals=2; plural=(n > 1);");
